@@ -1,24 +1,21 @@
 package Sort::Hash;
 use Exporter 'import';    # gives you Exporter's import() method directly
-use Try::Tiny '0.13';
-use Scalar::Util '1.24';
+use Try::Tiny 0.13;
+use Scalar::Util 1.24;
 use strict;
 use warnings FATAL => 'all';
 
 our @EXPORT = qw( sort_hash );    # symbols to export on request
 
-
-our $VERSION = '1.02';
-
-# ABSTRACT: Hash Sorting.
+our $VERSION = '1.04';
 
 =head1 NAME
 
-Sort::Hash
+Sort::Hash get the keys to a hashref sorted by their values
 
 =head1 VERSION 
 
-1.02
+1.04
 
 =head1 SYNOPSIS
 
@@ -31,7 +28,7 @@ the sort may be either Ascending or Descending.
   my @sorted = sort_hash( %some_hash );
   
 This does exactly the same as:
-  my @sorted = ( sort { $H{$a} <=> $H{$b} } keys  %some_hash ) ;
+  my @sorted = ( sort { $H{$a} <=> $H{$b} } keys  %H ) ;
   
 =head1 Description  
   
